.. py:module:: cerebral
               
cerebral
========

Models
------
.. python-apigen-group:: models

Loss
----
.. python-apigen-group:: loss

Metrics
-------
.. python-apigen-group:: metrics

K-folds cross-validation
------------------------
.. python-apigen-group:: kfolds

Feature Permutation
-------------------
.. python-apigen-group:: permutation

Hyperparameter Tuning
---------------------
.. python-apigen-group:: tuning
                         
Plot
----
.. python-apigen-group:: plots
                         
Utilities
---------
.. python-apigen-group:: utils
